*******************************
The sherpa.plot.backends module
*******************************

.. currentmodule:: sherpa.plot.backends

.. automodule:: sherpa.plot.backends

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      MetaBaseBackend
      BaseBackend
      BasicBackend
      IndepOnlyBackend

   .. rubric:: Constants

   .. autosummary::
       :toctree: api

       PLOT_BACKENDS
       backend_indep_colors
       backend_indep_kwargs
       kwargs_doc

Class Inheritance Diagram
=========================

.. inheritance-diagram::   MetaBaseBackend BaseBackend BasicBackend IndepOnlyBackend
   :parts: 1